package eu.hocke.roman.rquiz;

import android.content.Context;
import android.view.View;
import android.widget.Button;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

import java.io.IOException;
import java.util.LinkedHashMap;
import java.util.Map;

public class QuizOptionSet {

    private Map<String, String> quizOptions = new LinkedHashMap<String, String>();

    public static QuizOptionSet parseFromXml(XmlPullParser parser) throws IOException, XmlPullParserException {

        QuizOptionSet result = new QuizOptionSet();
        while (parser.nextTag() != XmlPullParser.END_TAG) {

            if (parser.getEventType() != XmlPullParser.START_TAG)
                throw new IllegalArgumentException("unexpected XML event \"" + parser.getEventType() + "\"");

            if (!parser.getName().equals("option"))
                throw new IllegalArgumentException("unexpected XML tag \"" + parser.getName() + "\"");

            String alias = parser.getAttributeValue(null, "alias");
            result.setOption(alias, parser.nextText());
        }

        return result;
    }

    public void setOption(String id, String option) {

        quizOptions.put(id, option.trim());
    }

    public String getOptionById(String id) {

        return quizOptions.get(id);
    }

    public Map<String, Button> createButtons(Context context, View.OnClickListener onClickListener) {

        Map<String, Button> result = new LinkedHashMap<>();
        for (Map.Entry entry : quizOptions.entrySet()) {

            Button button = new Button(context);
            button.setText((String)entry.getValue());
            button.setOnClickListener(onClickListener);
            result.put((String)entry.getKey(), button);
        }

        return result;
    }
}
