package eu.hocke.roman.rquiz;

import android.content.Context;
import android.view.View;
import android.widget.Button;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import java.io.IOException;
import java.util.Map;

public class QuizQuestion {

    private String question;

    private String correctAnswer;

    private QuizOptionSet optionSet;

    public QuizQuestion(String question, QuizOptionSet optionSet, String correctAnswer) {

        if (optionSet.getOptionById(correctAnswer) == null)
            throw new IllegalArgumentException("correct answer \"" + correctAnswer + "\" not present in options set");

        this.question       = question.trim();
        this.correctAnswer  = correctAnswer;
        this.optionSet      = optionSet;
    }

    public static QuizQuestion parseFromXml(XmlPullParser parser, Map<String, QuizOptionSet> optionSets) throws IOException, XmlPullParserException {

        String question, optionSetId, answer;

        optionSetId = parser.getAttributeValue(null, "optionset");
        answer = parser.getAttributeValue(null, "answer");
        question = parser.nextText();

        return new QuizQuestion(question, optionSets.get(optionSetId), answer);
    }

    public Map<String, Button> createButtons(Context context, View.OnClickListener onClickListener) {

        return optionSet.createButtons(context, onClickListener);
    }

    public String getQuestionText() {

        return question;
    }

    public boolean isCorrectAnswer(String answer) {

        return correctAnswer.equals(answer);
    }
}
